@@ -4,4 +4,4 @@
 # parameter: baseBranch = $1
 
 # clone all repos except droolsjbpm-build-bootstrap as this is supposed to be cloned before this script and has to be available
-./droolsjbpm-build-bootstrap/script/git-clone-others.sh --branch $1 --depth 70
\ No newline at end of file
+./droolsjbpm-build-bootstrap/script/git-clone-others.sh --branch $1 --depth 70 --no-single-branch
\ No newline at end of file
